---
name: Documentation
about: How Can We Improve the Documentation
title: "[DOCS]"
labels: documentation
assignees: paddyroddy
---

**Which Section of the Documentation Needs Improving?**
Please provide a link (if it is a specific page).

**What Can be Improved About This Section**
Is it incomplete, incorrect or difficult to understand?

**How to Improve This Section**
Do you have any specific suggestions we could take to improve the documentation?
